@@ -1,10 +1,9 @@
 deliverChart <- function(div_id,
                         running_in_shiny = TRUE){
-  
-  to_eval <- paste("uiOutput(\"",
+
+  to_eval <- paste0("uiOutput(\"",
                    div_id,
-                   "\")",
-                   sep="")
+                   "\")")
 
   if(running_in_shiny == TRUE){
     eval(parse(text = to_eval)
